=== modified file 'NEWS'
--- NEWS	2006-10-31 04:02:42 +0000
+++ NEWS	2006-10-31 19:34:44 +0000
@@ -10,6 +10,8 @@
   
   BUG FIXES:
 
+    * ``bzr ignore`` takes multiple arguments. (Cheuksan Edward Wang, #29488)
+
     * mv correctly handles paths that traverse symlinks. 
       (Aaron Bentley, #66964)
 
@@ -133,7 +135,7 @@
     * Leave HttpTransportBase daughter classes decides how they
       implement cloning. (Vincent Ladeuil, #61606)
 
-   * diff3 does not indicate conflicts on clean merge. (Aaron Bentley)
+    * diff3 does not indicate conflicts on clean merge. (Aaron Bentley)
 
   TESTING:
 

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2006-10-30 14:56:33 +0000
+++ bzrlib/builtins.py	2006-10-31 19:34:44 +0000
@@ -1540,7 +1540,7 @@
 
 
 class cmd_ignore(Command):
-    """Ignore a command or pattern.
+    """Ignore specified files or patterns.
 
     To remove patterns from the ignore list, edit the .bzrignore file.
 
@@ -1558,21 +1558,22 @@
         bzr ignore '*.class'
     """
     # TODO: Complain if the filename is absolute
-    takes_args = ['name_pattern?']
+    takes_args = ['name_pattern*']
     takes_options = [
                      Option('old-default-rules',
                             help='Out the ignore rules bzr < 0.9 always used.')
                      ]
     
-    def run(self, name_pattern=None, old_default_rules=None):
+    def run(self, name_pattern_list=None, old_default_rules=None):
         from bzrlib.atomicfile import AtomicFile
         if old_default_rules is not None:
             # dump the rules and exit
             for pattern in ignores.OLD_DEFAULTS:
                 print pattern
             return
-        if name_pattern is None:
-            raise errors.BzrCommandError("ignore requires a NAME_PATTERN")
+        if name_pattern_list is None or name_pattern_list == []:
+            raise errors.BzrCommandError("ignore requires at least one "
+                                  "NAME_PATTERN or --old-default-rules")
         tree, relpath = WorkingTree.open_containing(u'.')
         ifn = tree.abspath('.bzrignore')
         if os.path.exists(ifn):
@@ -1589,9 +1590,10 @@
 
         if igns and igns[-1] != '\n':
             igns += '\n'
-        igns += name_pattern + '\n'
+        for name_pattern in name_pattern_list:
+            igns += name_pattern + '\n'
 
-        f = AtomicFile(ifn, 'wt')
+        f = AtomicFile(ifn, 'wb')
         try:
             f.write(igns.encode('utf-8'))
             f.commit()

=== modified file 'bzrlib/tests/blackbox/test_ignore.py'
--- bzrlib/tests/blackbox/test_ignore.py	2006-10-16 01:25:46 +0000
+++ bzrlib/tests/blackbox/test_ignore.py	2006-10-31 19:34:44 +0000
@@ -67,14 +67,23 @@
         self.assertEquals(self.capture('unknowns'), 'foo.blah\n')
         self.runbzr('ignore *.blah')
         self.assertEquals(self.capture('unknowns'), '')
-        self.assertEquals('*.blah\n', open('.bzrignore', 'rU').read())
+        self.check_file_contents('.bzrignore', '*.blah\n')
 
         # 'ignore' works when then .bzrignore file already exists
         file('garh', 'wt').write('garh')
         self.assertEquals(self.capture('unknowns'), 'garh\n')
         self.runbzr('ignore garh')
         self.assertEquals(self.capture('unknowns'), '')
-        self.assertEquals(file('.bzrignore', 'rU').read(), '*.blah\ngarh\n')
+        self.check_file_contents('.bzrignore', '*.blah\ngarh\n')
+       
+    def test_ignore_multiple_arguments(self): 
+        """'ignore' works with multiple arguments"""
+        self.runbzr('init')
+        self.build_tree(['a','b','c','d'])
+        self.assertEquals(self.capture('unknowns'), 'a\nb\nc\nd\n')
+        self.runbzr('ignore a b c')
+        self.assertEquals(self.capture('unknowns'), 'd\n')
+        self.check_file_contents('.bzrignore', 'a\nb\nc\n')
         
     def test_ignore_old_defaults(self):
         out, err = self.run_bzr('ignore', '--old-default-rules')

